import request from '@/utils/request'


/**
 * 查询接口
 */

// 获取物料列表信息以及表头字段
const materialList = (data) => {

  return request({
    url: `/system/material/list`,
    method: 'post',
    data: data
  })
}

// 表头数据 | 表单控件
const tagList = (data) => {
  return request({
    url: `/system/tag/list`,
    method: 'post',
    data: data
  })
}

// 获取物料基本信息详细信息
const materialDetails = (id, templateCode) => {
  return request({
    url: `/system/material/details/${id}`,
    method: 'get',
    params: { templateCode }
  })
}

// 获取医药行业信息详细信息+表单属性
const medcineDetails = (id, templateCode) => {
  return request({
    url: `/system/medcine/details/${id}`,
    method: 'get',
    params: { templateCode }
  })
}

// 查询成本信息列表
const costList = (data) => {
  return request({
    url: `/system/cost/list`,
    method: 'post',
    data: data
  })
}

// 成本信息详情 
const costDetails = (id) => {
  return request({
    url: `/system/cost/details/${id}`,
    method: 'get',
    params: {}
  })
}


// 查询财务信息列表
const financeList = (data) => {
  return request({
    url: `/system/finance/list`,
    method: 'post',
    data: data
  })
}

// 获取财务信息详细信息 /dev-api/drp-admin/system/finance/details/{id}
const financeDetails = (id) => {
  return request({
    url: `/system/finance/details/${id}`,
    method: 'get',
    params: {}
  })
}



// 获取物料辅助属性详细信息
const propertyDetails = (id) => {
  return request({
    url: `/system/property/details/${id}`,
    method: 'get',
    params: {}
  })
}

// 查询物料辅助属性列表
const propertyList = (data) => {
  return request({
    url: `/system/property/list`,
    method: 'post',
    data: data
  })
}

//获取辅助计量单位基本信息
const unitDetails = (materialId, templateCode, id) => {
  return request({
    url: `/system/unit/details/${materialId}`,
    method: 'get',
    params: { templateCode, id }
  })
}

//获取辅计量管理列表信息
const unitList = (data) => {
  return request({
    url: `/system/unit/list`,
    method: 'post',
    data: data
  })
}

// 查询计划信息列表
const planList = (data) => {
  return request({
    url: `/system/plan/list`,
    method: 'post',
    data: data
  })
}

// 查询计划信息详情 
const planDetails = () => {
  return request({
    url: `/system/plan/details/${id}`,
    method: 'get',
    params: {}
  })
}

// 获取利润中心信息列表 
const centerList = (data) => {
  return request({
    url: `/system/center/list`,
    method: 'post',
    data: data
  })
}

// 获取利润中心详细信息 
const centerDetails = (id) => {
  return request({
    url: `/system/center/details/${id}`,
    method: 'get',
    params: {}
  })
}

// 获取采购信息列表  
const purchaseList = (data) => {
  return request({
    url: `/system/purchase/list`,
    method: 'post',
    data: data
  })
}

// 获取采购详细信息 
const purchaseDetails = (id) => {
  return request({
    url: `/system/purchase/details/${id}`,
    method: 'get',
    params: {}
  })
}

// 获取库存信息列表  
const inventoryList = (data) => {
  return request({
    url: `/system/inventory/list`,
    method: 'post',
    data: data
  })
}

// 获取库存详细信息 
const inventoryDetails = (id) => {
  return request({
    url: `/system/inventory/details/${id}`,
    method: 'get',
    params: {}
  })
}


// 根据参数动态执行方法  -输入框点击弹窗出现数据查询
const executeMethods = (methodName, data) => {
  return request({
    url: `/system/archival/${methodName}`,
    // url: `/system/archival/queryDosageForm`,
    method: 'post',
    data: data
  })
}



/**
 * 修改接口
 */
// 修改物料基本信息 /dev-api/drp-admin/system/material/edit
const materialEdit = (data) => {
  return request({
    url: `/system/material/edit`,
    method: 'post',
    data: data
  })
}

// 修改医药行业信息 /dev-api/drp-admin/system/medcine/edit   
const medcineEdit = (data) => {
  return request({
    url: `/system/medcine/edit `,
    method: 'post',
    data: data
  })
}

// 保存物料以及相关页签 material
const saveMaterial = (data) => {
  return request({
    url: `/system/material/saveMaterial `,
    method: 'post',
    data: data
  })
}

// 保存物料以及医药行业接口 /dev-api/drp-admin/system/material/insertMaterialInfo
const insertMaterialInfo = (data) => {
  return request({
    url: `/system/material/insertMaterialInfo `,
    method: 'post',
    data: data
  })
}

export default {
  // 查询
  materialList,
  tagList,
  materialDetails,
  medcineDetails,
  costList,
  costDetails,
  financeList,
  financeDetails,
  propertyDetails,
  propertyList,
  unitDetails,
  unitList,
  planList,
  planDetails,
  centerList,
  centerDetails,
  purchaseList,
  purchaseDetails,
  inventoryList,
  inventoryDetails,
  executeMethods,
  // 编辑
  materialEdit,
  medcineEdit,
  saveMaterial,
  insertMaterialInfo,
  
}